pub struct EpistemicEvidence {
pub epistemic_mode: String,
pub know_operator_count: usize,
pub possible_operator_count: usize,
pub accepted_candidates: usize,
pub rejected_candidates: usize,
pub accepted_world_views: usize,
pub final_output_rows: usize,
}Expand description
Summary of one accepted epistemic GPU execution.
accepted_world_views == 0 means the program ran but nothing was accepted.
evaluate_conditioned on that same program RAISES RuntimeError rather than
returning an unconditioned result — this method is the non-raising way to detect
the state. know_operator_count/possible_operator_count are plan-level
censuses and stay non-zero even when nothing is accepted.
Fields
epistemic_mode: Stringknow_operator_count: usizepossible_operator_count: usizeaccepted_candidates: usizerejected_candidates: usizeaccepted_world_views: usizefinal_output_rows: usizeTrait Implementations
impl DerefToPyAny for EpistemicEvidence
impl ExtractPyClassWithClone for EpistemicEvidence
Sourceimpl<'py> IntoPyObject<'py> for EpistemicEvidence
impl<'py> IntoPyObject<'py> for EpistemicEvidence
Sourcetype Target = EpistemicEvidence
type Target = EpistemicEvidence
The Python output type
Sourcetype Output = Bound<'py, <EpistemicEvidence as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <EpistemicEvidence as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for EpistemicEvidence
impl PyClass for EpistemicEvidence
Sourceimpl PyClassImpl for EpistemicEvidence
impl PyClassImpl for EpistemicEvidence
Sourceconst MODULE: Option<&str> = ::core::option::Option::None
const MODULE: Option<&str> = ::core::option::Option::None
Module which the class will be associated with. Read more
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// censuses and stay non-zero even when nothing is accepted.
const RAW_DOC: &'static CStr = /// censuses and stay non-zero even when nothing is accepted.
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<EpistemicEvidence as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<EpistemicEvidence>
type Layout = <<EpistemicEvidence as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<EpistemicEvidence>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
type Inventory = Pyo3MethodsInventoryForEpistemicEvidence
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
fn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyTypeInfo for EpistemicEvidence
impl PyTypeInfo for EpistemicEvidence
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Auto Trait Implementations
impl Freeze for EpistemicEvidence
impl RefUnwindSafe for EpistemicEvidence
impl Send for EpistemicEvidence
impl Sync for EpistemicEvidence
impl Unpin for EpistemicEvidence
impl UnsafeUnpin for EpistemicEvidence
impl UnwindSafe for EpistemicEvidence