pub struct IlpTaggedCreditDeviceResult {
pub fact_row_offsets: Py<PyAny>,
pub entry_indices: Py<PyAny>,
pub entry_i: Py<PyAny>,
pub entry_j: Py<PyAny>,
pub entry_k: Py<PyAny>,
}Fields
fact_row_offsets: Py<PyAny>entry_indices: Py<PyAny>entry_i: Py<PyAny>entry_j: Py<PyAny>entry_k: Py<PyAny>Trait Implementations
impl DerefToPyAny for IlpTaggedCreditDeviceResult
impl ExtractPyClassWithClone for IlpTaggedCreditDeviceResult
Sourceimpl<'py> IntoPyObject<'py> for IlpTaggedCreditDeviceResult
impl<'py> IntoPyObject<'py> for IlpTaggedCreditDeviceResult
Sourcetype Target = IlpTaggedCreditDeviceResult
type Target = IlpTaggedCreditDeviceResult
The Python output type
Sourcetype Output = Bound<'py, <IlpTaggedCreditDeviceResult as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <IlpTaggedCreditDeviceResult as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for IlpTaggedCreditDeviceResult
impl PyClass for IlpTaggedCreditDeviceResult
Sourceimpl PyClassImpl for IlpTaggedCreditDeviceResult
impl PyClassImpl for IlpTaggedCreditDeviceResult
Sourceconst MODULE: Option<&str> = ::core::option::Option::None
const MODULE: Option<&str> = ::core::option::Option::None
Module which the class will be associated with. Read more
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<IlpTaggedCreditDeviceResult as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<IlpTaggedCreditDeviceResult>
type Layout = <<IlpTaggedCreditDeviceResult as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<IlpTaggedCreditDeviceResult>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
type Inventory = Pyo3MethodsInventoryForIlpTaggedCreditDeviceResult
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
fn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyTypeInfo for IlpTaggedCreditDeviceResult
impl PyTypeInfo for IlpTaggedCreditDeviceResult
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Auto Trait Implementations
impl !RefUnwindSafe for IlpTaggedCreditDeviceResult
impl Freeze for IlpTaggedCreditDeviceResult
impl Send for IlpTaggedCreditDeviceResult
impl Sync for IlpTaggedCreditDeviceResult
impl Unpin for IlpTaggedCreditDeviceResult
impl UnsafeUnpin for IlpTaggedCreditDeviceResult
impl UnwindSafe for IlpTaggedCreditDeviceResult