pub struct McDeviceEvalResult {Show 20 fields
pub query_counts: Py<PyAny>,
pub evidence_count: Py<PyAny>,
pub total_samples: usize,
pub seed: u64,
pub confidence: f64,
pub nonmonotone_semantics: String,
pub nonmonotone_sccs: usize,
pub nonmonotone_cycles: usize,
pub nonmonotone_iteration_limit_hits: usize,
pub sampling_method: String,
pub resident_no_host_certified: bool,
pub resident_no_host_policy_result: String,
pub resident_no_host_tracked_dtoh_calls: u64,
pub resident_no_host_tracked_htod_calls: u64,
pub resident_no_host_host_loop_iterations: u64,
pub resident_no_host_per_sample_host_launches: u64,
pub resident_no_host_untracked_metadata_reads: u64,
pub resident_no_host_engine_launches: u64,
pub resident_no_host_host_fixpoint_iterations: u64,
pub resident_no_host_per_operator_host_allocations: u64,
}Fields
query_counts: Py<PyAny>Per-query satisfying-sample counts. DLPack int32 tensor on CUDA.
evidence_count: Py<PyAny>Evidence satisfying-sample count. DLPack int32 tensor with shape [1] on CUDA.
total_samples: usizeseed: u64confidence: f64nonmonotone_semantics: Stringnonmonotone_sccs: usizenonmonotone_cycles: usizenonmonotone_iteration_limit_hits: usizesampling_method: Stringresident_no_host_certified: boolresident_no_host_policy_result: Stringresident_no_host_tracked_dtoh_calls: u64resident_no_host_tracked_htod_calls: u64resident_no_host_host_loop_iterations: u64resident_no_host_per_sample_host_launches: u64resident_no_host_untracked_metadata_reads: u64resident_no_host_engine_launches: u64resident_no_host_host_fixpoint_iterations: u64resident_no_host_per_operator_host_allocations: u64Trait Implementations
impl DerefToPyAny for McDeviceEvalResult
impl ExtractPyClassWithClone for McDeviceEvalResult
Sourceimpl<'py> IntoPyObject<'py> for McDeviceEvalResult
impl<'py> IntoPyObject<'py> for McDeviceEvalResult
Sourcetype Target = McDeviceEvalResult
type Target = McDeviceEvalResult
The Python output type
Sourcetype Output = Bound<'py, <McDeviceEvalResult as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <McDeviceEvalResult as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for McDeviceEvalResult
impl PyClass for McDeviceEvalResult
Sourceimpl PyClassImpl for McDeviceEvalResult
impl PyClassImpl for McDeviceEvalResult
Sourceconst MODULE: Option<&str> = ::core::option::Option::None
const MODULE: Option<&str> = ::core::option::Option::None
Module which the class will be associated with. Read more
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<McDeviceEvalResult as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<McDeviceEvalResult>
type Layout = <<McDeviceEvalResult as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<McDeviceEvalResult>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
type Inventory = Pyo3MethodsInventoryForMcDeviceEvalResult
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
fn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyTypeInfo for McDeviceEvalResult
impl PyTypeInfo for McDeviceEvalResult
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Auto Trait Implementations
impl !RefUnwindSafe for McDeviceEvalResult
impl Freeze for McDeviceEvalResult
impl Send for McDeviceEvalResult
impl Sync for McDeviceEvalResult
impl Unpin for McDeviceEvalResult
impl UnsafeUnpin for McDeviceEvalResult
impl UnwindSafe for McDeviceEvalResult